@@ -21,7 +21,7 @@ setGeneric("lmmpower")
 #' 
 #' @name lmmpower
 #' @aliases lmmpower-methods lmmpower,ANY-method lmmpower,merMod-method
-#' lmmpower.default lmmpower.lme lmmpower.gee lmmpower.numeric
+#' lmmpower.default lmmpower.lme lmmpower.gee lmmpower.numeric lmmpower.double
 #' @docType methods
 #' @param object an object returned by lme4
 #' @param n sample size per group
@@ -108,6 +108,7 @@ setGeneric("lmmpower")
 #' lmmpower(fm4, pct.change = 0.30, t = seq(0,9,1), power = 0.80)
 #' }
 #' 
+#' @method lmmpower default
 #' @export
 lmmpower.default <- function(object=NULL,
    n=NULL,
@@ -212,9 +213,15 @@ lmmpower.default <- function(object=NULL,
 }
 
 #' @export
+#' @method lmmpower double
+lmmpower.double <- lmmpower.default
+
+#' @export
+#' @method lmmpower numeric
 lmmpower.numeric <- lmmpower.default
 
 #' @importFrom nlme getVarCov
+#' @method lmmpower lme
 #' @export
 lmmpower.lme <- function(object,
    n = NULL,
@@ -288,6 +295,7 @@ lmmpower.lme <- function(object,
     tol=tol, ...)
 }
 
+#' @method lmmpower gee
 #' @export
 lmmpower.gee <- function(object,
    n = NULL,
